@@ -36,7 +36,6 @@ HAS_ACCOUNT_DEFAULT = _ACCOUNTDEFAULT()
 
 
 BoolSettings = Literal[
-    'additional_uri_schemes',
     'allow_open_file_uris',
     'always_english_wikipedia',
     'always_english_wiktionary',
@@ -129,6 +128,7 @@ IntSettings = Literal[
 
 StringSettings = Literal[
     'action_on_close',
+    'additional_uri_schemes',
     'audio_input_device',
     'audio_output_device',
     'autoaway_message',
@@ -375,6 +375,7 @@ BoolGroupChatSettings = Literal[
 
 StringGroupChatSettings = Literal[
     'encryption',
+    'mute_until',
     'speller_language',
     'send_chatstate',
 ]
@@ -397,6 +398,7 @@ BoolContactSettings = Literal[
 
 StringContactSettings = Literal[
     'encryption',
+    'mute_until',
     'speller_language',
     'send_chatstate',
 ]
@@ -478,6 +480,7 @@ ACCOUNT_SETTINGS = {
 
     'contact': {
         'encryption': '',
+        'mute_until': '',
         'send_chatstate': HAS_ACCOUNT_DEFAULT,
         'send_marker': HAS_ACCOUNT_DEFAULT,
         'speller_language': '',
@@ -485,6 +488,7 @@ ACCOUNT_SETTINGS = {
 
     'group_chat': {
         'encryption': '',
+        'mute_until': '',
         'notify_on_all_messages': HAS_APP_DEFAULT,
         'print_join_left': HAS_APP_DEFAULT,
         'print_status': HAS_APP_DEFAULT,
@@ -584,6 +588,11 @@ PROXY_EXAMPLES = {
         'host': 'localhost',
         'port': 9050
     },
+    'Tor (Browser)': {
+        'type': 'socks5',
+        'host': 'localhost',
+        'port': 9150
+    },
 }
 
 
