@@ -18,6 +18,7 @@ from typing import Any
 from typing import Optional
 
 import pickle
+from datetime import datetime
 from urllib.parse import urlparse
 
 import cairo
@@ -107,6 +108,13 @@ class ChatListRow(Gtk.ListBoxRow):
         self.connect('state-flags-changed', self._on_state_flags_changed)
         self.connect('destroy', self._on_destroy)
 
+        app.settings.connect_signal(
+            'mute_until',
+            self._on_mute_setting_changed,
+            self.contact.account,
+            self.contact.jid)
+        self._on_mute_setting_changed()
+
         # Drag and Drop
         entries = [Gtk.TargetEntry.new(
             'CHAT_LIST_ITEM',
@@ -324,7 +332,7 @@ class ChatListRow(Gtk.ListBoxRow):
         if self.timestamp == 0:
             return
         self._ui.timestamp_label.set_text(
-            get_uf_relative_time(self.timestamp))
+            get_uf_relative_time(datetime.fromtimestamp(self.timestamp)))
 
     def add_unread(self, text: str) -> None:
         self._unread_count += 1
@@ -375,6 +383,9 @@ class ChatListRow(Gtk.ListBoxRow):
             return str(count)
         return '999+'
 
+    def _on_mute_setting_changed(self, *args: Any) -> None:
+        self._ui.mute_image.set_visible(self.contact.is_muted)
+
     def _on_draft_update(self,
                          _draft_storage: DraftStorage,
                          _signal_name: str,
@@ -408,6 +419,7 @@ class ChatListRow(Gtk.ListBoxRow):
             self._ui.revealer.set_reveal_child(False)
 
     def _on_destroy(self, _row: ChatListRow) -> None:
+        app.settings.disconnect_signals(self)
         self.contact.disconnect_all_from_obj(self)
         if isinstance(self.contact, GroupchatParticipant):
             self.contact.room.disconnect_all_from_obj(self)
